quick_notes.api.to_toml module

Parse markdown string to NotRenderedQuickNoteList.

quick_notes.api.to_toml.parse(markdown_str: str) NotRenderedQuickNoteList[source]

Convert a markdown string containing one or more quick note into a non rendered QuickNoteList.

Parameters:

markdown_str (str) – A markdown string containing one or more markdown quick-note.

Returns:

A list of QuickNote.

Return type:

NotRenderedQuickNoteList